/// <reference types="node" />
export declare enum DataTypes {
    BYTE = 0,
    BOOL = 1,
    INT8 = 2,
    INT16 = 3,
    INT32 = 4,
    UINT8 = 5,
    UINT16 = 6,
    UINT32 = 7,
    FLOAT = 8,
    DOUBLE = 9,
    DATE = 10,
    STRING = 11,
    BYTE_ARRAY = 12
}
interface WriteOptions {
    insert?: boolean;
}
export declare class ByteList {
    static SetBit(num: number, val: boolean, bit: number): number;
    static GetBit(num: number, bit: number): boolean;
    index: number;
    useLittleEndian: boolean;
    get length(): number;
    get paddingSize(): number;
    set paddingSize(val: number);
    private _paddingSize;
    private _length;
    private _buffer;
    constructor(bytes?: string | ArrayBuffer | Buffer | ByteList | number[]);
    getBuffer(): Buffer;
    getLength(): number;
    concat(bytes: ArrayBuffer | Buffer | ByteList | number[]): void;
    insert(buffer: Buffer | ByteList | Uint8Array): void;
    peekBits(startingBit: number, numberOfBits: number): number;
    peekByte(offset?: number): number;
    peekUInt16(offset?: number): number;
    peekUInt32(offset?: number): number;
    writeByte(byte: any, options?: WriteOptions): void;
    writeInt8(int8: number, options?: WriteOptions): void;
    writeBool(bool: boolean, options?: WriteOptions): void;
    writeInt16(int16: number, options?: WriteOptions): void;
    writeInt32(int32: number, options?: WriteOptions): void;
    writeUInt16(uint16: number, options?: WriteOptions): void;
    writeUInt32(uint32: number, options?: WriteOptions): void;
    writeFloat(float: number, options?: WriteOptions): void;
    writeDouble(double: number, options?: WriteOptions): void;
    writeDate(date: Date, options?: WriteOptions): void;
    writeString(str?: string, options?: {
        insert?: boolean;
        length?: number;
    }): void;
    writeByteArray(list: number[] | Buffer, options?: WriteOptions): void;
    writeData(type: DataTypes, val?: number | string | boolean | Date | number[] | Buffer, options?: WriteOptions): void;
    trimLeft(count: number): Buffer;
    trimRight(count: number): Buffer;
    readByte(): number;
    readInt8(): number;
    readBool(): boolean;
    readInt16(): number;
    readInt32(): number;
    readUInt16(): number;
    readUInt32(): number;
    readFloat(): number;
    readDouble(): number;
    readDate(): Date | null;
    readBytes(count: number): Buffer;
    readString(options?: {
        length?: number;
    }): string;
    readByteArray(): number[];
    readData(type: DataTypes.BYTE): number;
    readData(type: DataTypes.INT8): number;
    readData(type: DataTypes.UINT8): number;
    readData(type: DataTypes.INT16): number;
    readData(type: DataTypes.UINT16): number;
    readData(type: DataTypes.INT32): number;
    readData(type: DataTypes.UINT32): number;
    readData(type: DataTypes.FLOAT): number;
    readData(type: DataTypes.DOUBLE): number;
    readData(type: DataTypes.BYTE_ARRAY): number[];
    readData(type: DataTypes.BOOL): boolean;
    readData(type: DataTypes.DATE): Date;
    readData(type: DataTypes.STRING): string;
    toString(): string;
    private prepareBuffer;
}
export {};
